This is a subsample of the dataset Pix3D: http://pix3d.csail.mit.edu/.

Reference:

Pix3D: Dataset and Methods for Single-Image 3D Shape Modeling.

Xingyuan Sun, Jiajun Wu, Xiuming Zhang, Zhoutong Zhang, Chengkai Zhang, Tianfan Xue, Joshua B. Tenenbaum, and William T. Freeman
